==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QGridLayout_shell.h <==
#ifndef QGRIDLAYOUT_SHELL_H
#define QGRIDLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qgridlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGridLayout_shell : public QGridLayout, public QtJambiShellInterface
{
public:
    QGridLayout_shell();
    QGridLayout_shell(QWidget* parent0);
    ~QGridLayout_shell() override;

    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGridLayout_access : public QGridLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_maximumSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumHeightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QGRIDLAYOUT_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QGridLayout_shell.h <==
#ifndef QGRIDLAYOUT_SHELL_H
#define QGRIDLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qgridlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGridLayout_shell : public QGridLayout, public QtJambiShellInterface
{
public:
    QGridLayout_shell();
    QGridLayout_shell(QWidget* parent0);
    ~QGridLayout_shell() override;

    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGridLayout_access : public QGridLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_maximumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumHeightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QGRIDLAYOUT_SHELL_H
